@@ -388,7 +388,8 @@ class Path(Pattern):
         return request.url.path
 
     def strip_base(self, value: str) -> str:
-        value = urljoin("/", value[len(self.base.value) :])
+        value = value[len(self.base.value) :]
+        value = "/" + value if not value.startswith("/") else value
         return value
 
 
@@ -607,7 +608,7 @@ def merge_patterns(pattern: Pattern, **bases: Pattern) -> Pattern:
             # Pattern is "absolute", skip merging
             bases = None
         else:
-            # Traverse pattern and set releated base
+            # Traverse pattern and set related base
             for _pattern in patterns:
                 base = bases.pop(_pattern.key, None)
                 # Skip "exact" base + don't overwrite existing base
