@@ -1,7 +1,10 @@
 from typing import (
     Any,
+    AsyncIterable,
+    Awaitable,
     Callable,
     Dict,
+    Iterable,
     Iterator,
     List,
     Optional,
@@ -22,32 +25,7 @@ URL = Tuple[
     bytes,  # path
 ]
 Headers = List[Tuple[bytes, bytes]]
-ByteStream = Union[httpx.SyncByteStream, httpx.AsyncByteStream]
-Request = Tuple[
-    bytes,  # http method
-    URL,
-    Headers,
-    ByteStream,  # body
-]
-SyncResponse = Tuple[
-    int,  # status code
-    Headers,
-    httpx.SyncByteStream,  # body
-    dict,  # ext
-]
-AsyncResponse = Tuple[
-    int,  # status code
-    Headers,
-    httpx.AsyncByteStream,  # body
-    dict,  # ext
-]
-Response = Tuple[
-    int,  # status code
-    Headers,
-    ByteStream,  # body
-    dict,  # ext
-]
-RequestHandler = Callable[[httpx.Request], httpx.Response]
+Content = Union[str, bytes, Iterable[bytes], AsyncIterable[bytes]]
 
 HeaderTypes = Union[
     httpx.Headers,
@@ -61,10 +39,13 @@ CookieTypes = Union[Dict[str, str], Sequence[Tuple[str, str]]]
 DefaultType = TypeVar("DefaultType", bound=Any)
 
 URLPatternTypes = Union[str, Pattern[str], URL, httpx.URL]
-QueryParamTypes = Union[bytes, str, List[Tuple[str, Any]], Dict[str, Any]]
-RequestTypes = Union[Request, httpx.Request]
+QueryParamTypes = Union[
+    bytes, str, List[Tuple[str, Any]], Dict[str, Any], Tuple[Tuple[str, Any], ...]
+]
 
-CallableSideEffect = Callable[..., Optional[Union[httpx.Request, httpx.Response]]]
+ResolvedResponseTypes = Optional[Union[httpx.Request, httpx.Response]]
+RouteResultTypes = Union[ResolvedResponseTypes, Awaitable[ResolvedResponseTypes]]
+CallableSideEffect = Callable[..., RouteResultTypes]
 SideEffectListTypes = Union[httpx.Response, Exception, Type[Exception]]
 SideEffectTypes = Union[
     CallableSideEffect,
